****************************
The sherpa.astro.plot module
****************************

.. currentmodule:: sherpa.astro.plot

.. automodule:: sherpa.astro.plot

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      DataPHAPlot
      ModelPHAHistogram
      ModelHistogram
      SourcePlot
      ComponentModelPlot
      ComponentSourcePlot
      ARFPlot
      BkgDataPlot
      BkgModelPHAHistogram
      BkgModelHistogram
      BkgFitPlot
      BkgDelchiPlot
      BkgResidPlot
      BkgRatioPlot
      BkgChisqrPlot
      BkgSourcePlot
      OrderPlot
      FluxHistogram
      EnergyFluxHistogram
      PhotonFluxHistogram

Class Inheritance Diagram
=========================

.. inheritance-diagram::  DataPHAPlot ModelPHAHistogram ModelHistogram SourcePlot ComponentModelPlot ComponentSourcePlot ARFPlot BkgDataPlot BkgModelPHAHistogram BkgModelHistogram BkgFitPlot BkgDelchiPlot BkgResidPlot BkgRatioPlot BkgChisqrPlot BkgSourcePlot OrderPlot FluxHistogram EnergyFluxHistogram PhotonFluxHistogram
   :parts: 1
